@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use Moose;
 
@@ -138,7 +138,7 @@ Dist::Zilla::Plugin::Author::SKIRMESS::RepositoryBase - Automatically create and
 
 =head1 VERSION
 
-Version 0.014
+Version 0.015
 
 =head1 SYNOPSIS
 
@@ -478,8 +478,6 @@ install:
 script:
   - perl Makefile.PL && make test
   - test -d xt/author && prove -lr xt/author
-  - make manifest
-  - test -d xt/release && prove -lr xt/release
 TRAVIS_YML
 
         return $travis_yml;
@@ -674,6 +672,18 @@ version_all_ok;
 done_testing();
 XT_AUTHOR_TEST_VERSION_T
 
+=head2 xt/release/changes.t
+
+L<Test::CPAN::Changes|Test::CPAN::Changes> release test.
+
+=cut
+
+    $file{q{xt/release/changes.t}} = $test_header . <<'XT_RELEASE_CHANGES_T';
+use Test::CPAN::Changes;
+
+changes_ok();
+XT_RELEASE_CHANGES_T
+
 =head2 xt/release/eol.t
 
 L<Test::EOL|Test::EOL> release test.
